#
# spec file for package python3-pyparsing
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-pyparsing
Version:        2.0.3
Release:        4.2
Url:            http://pyparsing.wikispaces.com/
Summary:        Grammar Parser Library for Python
License:        MIT and GPL-2.0+ and GPL-3.0+
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/p/pyparsing/pyparsing-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python3
BuildRequires:  python3-2to3
BuildRequires:  python3-devel
BuildRequires:  python3-distribute
Requires:       python3
BuildArch:      noarch

%description
The pyparsing module is an alternative approach to creating and executing
simple grammars, vs. the traditional lex/yacc approach, or the use of regular
expressions. The pyparsing module provides a library of classes that client
code uses to construct the grammar directly in Python code.

%package doc
Summary:        Grammar Parser Library for Python - Documentation
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}

%description doc
The pyparsing module is an alternative approach to creating and executing
simple grammars, vs. the traditional lex/yacc approach, or the use of regular
expressions. The pyparsing module provides a library of classes that client
code uses to construct the grammar directly in Python code.

This package contains the documentation of %{name}

%prep
%setup -q -n pyparsing-%{version}

%build
python3 setup.py build
# Fix wrong EOL encoding:
sed -i 's/\r$//' CHANGES LICENSE README examples/*py

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc CHANGES LICENSE README
%{python3_sitelib}/*

%files doc
%defattr(-,root,root,-)
%doc docs/* examples

%changelog
* Sun Nov 30 2014 arun@gmx.de
- update to version 2.0.3:
  * Fixed escaping behavior in QuotedString. Formerly, only quotation
    marks (or characters designated as quotation marks in the QuotedString
    constructor) would be escaped. Now all escaped characters will be
    escaped, and the escaping backslashes will be removed.
  * Fixed regression in ParseResults.pop() - pop() was pretty much
    broken after I added *improvements* in 2.0.2. Reported by Iain
    Shelvington, thanks Iain!
  * Fixed bug in And class when initializing using a generator.
  * Enhanced ParseResults.dump() method to list out nested ParseResults that
    are unnamed arrays of sub-structures.
  * Fixed UnboundLocalError under Python 3.4 in oneOf method, reported
    on Sourceforge by aldanor, thanks!
  * Fixed bug in ParseResults __init__ method, when returning non-ParseResults
    types from parse actions that implement __eq__. Raised during discussion
    on the pyparsing wiki with cyrfer.
- changes from version 2.0.2:
  * Extended "expr(name)" shortcut (same as "expr.setResultsName(name)")
    to accept "expr()" as a shortcut for "expr.copy()".
  * Added "locatedExpr(expr)" helper, to decorate any returned tokens
    with their location within the input string. Adds the results names
    locn_start and locn_end to the output parse results.
  * Added "pprint()" method to ParseResults, to simplify troubleshooting
    and prettified output. Now instead of importing the pprint module
    and then writing "pprint.pprint(result)", you can just write
    "result.pprint()".  This method also accepts addtional positional and
    keyword arguments (such as indent, width, etc.), which get passed
    through directly to the pprint method
    (see http://docs.python.org/2/library/pprint.html#pprint.pprint).
  * Removed deprecation warnings when using '<<' for Forward expression
    assignment. '<<=' is still preferred, but '<<' will be retained
    for cases whre '<<=' operator is not suitable (such as in defining
    lambda expressions).
  * Expanded argument compatibility for classes and functions that
    take list arguments, to now accept generators as well.
  * Extended list-like behavior of ParseResults, adding support for
    append and extend. NOTE: if you have existing applications using
    these names as results names, you will have to access them using
    dict-style syntax: res["append"] and res["extend"]
  * ParseResults emulates the change in list vs. iterator semantics for
    methods like keys(), values(), and items(). Under Python 2.x, these
    methods will return lists, under Python 3.x, these methods will
    return iterators.
  * ParseResults now has a method haskeys() which returns True or False
    depending on whether any results names have been defined. This simplifies
    testing for the existence of results names under Python 3.x, which
    returns keys() as an iterator, not a list.
  * ParseResults now supports both list and dict semantics for pop().
    If passed no argument or an integer argument, it will use list semantics
    and pop tokens from the list of parsed tokens. If passed a non-integer
    argument (most likely a string), it will use dict semantics and
    pop the corresponding value from any defined results names. A
    second default return value argument is supported, just as in
    dict.pop().
  * Fixed bug in markInputline, thanks for reporting this, Matt Grant!
  * Cleaned up my unit test environment, now runs with Python 2.6 and
    3.3.
* Tue Dec  3 2013 arun@gmx.de
- update to 2.0.1 (bnc#209662):
  * Removed use of "nonlocal" that prevented using this version of
    pyparsing with Python 2.6 and 2.7. This will make it easier to
    install for packages that depend on pyparsing, under Python
    versions 2.6 and later. Those using older versions of Python
    will have to manually install pyparsing 1.5.7.
  * Fixed implementation of <<= operator to return self;
* Fri Apr 12 2013 toddrme2178@gmail.com
- Fix EOL fix
* Fri Apr 12 2013 toddrme2178@gmail.com
- Update to 2.0.0
  * Break compatibility with python <= 2.7
* Wed Mar 13 2013 dmueller@suse.com
- update to 1.5.7:
  * NOTE: This is the last release of pyparsing that will try to
  maintain compatibility with Python versions < 2.6. The next
  release of pyparsing will be version 2.0.0, using new Python
  syntax that will not be compatible for Python version 2.5 or
  older.
  * An awesome new example is included in this release, submitted
  by Luca DellOlio, for parsing ANTLR grammar definitions, nice
  work Luca!
  * Fixed implementation of ParseResults.__str__ to use Pythonic
  ''.join() instead of repeated string concatenation. This
  purportedly has been a performance issue under PyPy.
  * Fixed bug in ParseResults.__dir__ under Python 3, reported by
  Thomas Kluyver, thank you Thomas!
  * Added ParserElement.inlineLiteralsUsing static method, to
  override pyparsing's default behavior of converting string
  literals to Literal instances, to use other classes (such
  as Suppress or CaselessLiteral).
  * Added new operator '<<=', which will eventually replace '<<' for
  storing the contents of a Forward(). '<<=' does not have the same
  operator precedence problems that '<<' does.
  * 'operatorPrecedence' is being renamed 'infixNotation' as a better
  description of what this helper function creates. 'operatorPrecedence'
  is deprecated, and will be dropped entirely in a future release.
  * Added optional arguments lpar and rpar to operatorPrecedence, so that
  expressions that use it can override the default suppression of the
  grouping characters.
  * Added support for using single argument builtin functions as parse
  actions.  Now you can write 'expr.setParseAction(len)' and get back
  the length of the list of matched tokens.  Supported builtins are:
  sum, len, sorted, reversed, list, tuple, set, any, all, min, and max.
  A script demonstrating this feature is included in the examples
  directory.
  * Fixed a bug in the definition of 'alphas', which was based on the
  string.uppercase and string.lowercase "constants", which in fact
  * aren't* constant, but vary with locale settings. This could make
  parsers locale-sensitive in a subtle way. Thanks to Kef Schecter for
  his diligence in following through on reporting and monitoring
  this bugfix!
  * Fixed a bug in the Py3 version of pyparsing, during exception
  handling with packrat parsing enabled, reported by Catherine
  Devlin - thanks Catherine!
  * Fixed typo in ParseBaseException.__dir__, reported anonymously on
  the SourceForge bug tracker, thank you Pyparsing User With No Name.
  * Fixed bug in srange when using '\x###' hex character codes.
  * Addeed optional 'intExpr' argument to countedArray, so that you
  can define your own expression that will evaluate to an integer,
  to be used as the count for the following elements. Allows you
  to define a countedArray with the count given in hex, for example,
  by defining intExpr as "Word(hexnums).setParseAction(int(t[0],16))".
* Mon Jan 14 2013 saschpe@suse.de
- Fix license (MIT and GPL-2.0+ and GPL-3.0+)
* Wed Jan  9 2013 saschpe@suse.de
- Don't ship examples twice
* Mon Jan  7 2013 p.drouand@gmail.com
- Initial support of python3
